/* app-window.c generated by valac 0.32.0.6-ea53, the Vala compiler
 * generated from app-window.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <libgd/gd.h>
#include <glib/gi18n-lib.h>
#include <stdlib.h>
#include <string.h>
#include <gdk/gdk.h>
#include <libcommon.h>
#include <atk/atk.h>


#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;
typedef struct _BoxesAppWindowPrivate BoxesAppWindowPrivate;

#define BOXES_TYPE_WIZARD_WINDOW (boxes_wizard_window_get_type ())
#define BOXES_WIZARD_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindow))
#define BOXES_WIZARD_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindowClass))
#define BOXES_IS_WIZARD_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_WINDOW))
#define BOXES_IS_WIZARD_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_WINDOW))
#define BOXES_WIZARD_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindowClass))

typedef struct _BoxesWizardWindow BoxesWizardWindow;
typedef struct _BoxesWizardWindowClass BoxesWizardWindowClass;

#define BOXES_TYPE_PROPERTIES_WINDOW (boxes_properties_window_get_type ())
#define BOXES_PROPERTIES_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindow))
#define BOXES_PROPERTIES_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindowClass))
#define BOXES_IS_PROPERTIES_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES_WINDOW))
#define BOXES_IS_PROPERTIES_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES_WINDOW))
#define BOXES_PROPERTIES_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindowClass))

typedef struct _BoxesPropertiesWindow BoxesPropertiesWindow;
typedef struct _BoxesPropertiesWindowClass BoxesPropertiesWindowClass;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_ICON_VIEW (boxes_icon_view_get_type ())
#define BOXES_ICON_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_ICON_VIEW, BoxesIconView))
#define BOXES_ICON_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_ICON_VIEW, BoxesIconViewClass))
#define BOXES_IS_ICON_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_ICON_VIEW))
#define BOXES_IS_ICON_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_ICON_VIEW))
#define BOXES_ICON_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_ICON_VIEW, BoxesIconViewClass))

typedef struct _BoxesIconView BoxesIconView;
typedef struct _BoxesIconViewClass BoxesIconViewClass;

#define BOXES_TYPE_LIST_VIEW (boxes_list_view_get_type ())
#define BOXES_LIST_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIST_VIEW, BoxesListView))
#define BOXES_LIST_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIST_VIEW, BoxesListViewClass))
#define BOXES_IS_LIST_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIST_VIEW))
#define BOXES_IS_LIST_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIST_VIEW))
#define BOXES_LIST_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIST_VIEW, BoxesListViewClass))

typedef struct _BoxesListView BoxesListView;
typedef struct _BoxesListViewClass BoxesListViewClass;

#define BOXES_APP_WINDOW_TYPE_VIEW_TYPE (boxes_app_window_view_type_get_type ())

#define BOXES_TYPE_ICOLLECTION_VIEW (boxes_icollection_view_get_type ())
#define BOXES_ICOLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_ICOLLECTION_VIEW, BoxesICollectionView))
#define BOXES_IS_ICOLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_ICOLLECTION_VIEW))
#define BOXES_ICOLLECTION_VIEW_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_ICOLLECTION_VIEW, BoxesICollectionViewIface))

typedef struct _BoxesICollectionView BoxesICollectionView;
typedef struct _BoxesICollectionViewIface BoxesICollectionViewIface;

#define BOXES_TYPE_SELECTION_CRITERIA (boxes_selection_criteria_get_type ())

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_variant_unref0(var) ((var == NULL) ? NULL : (var = (g_variant_unref (var), NULL)))

#define BOXES_TYPE_KBD_SHORTCUTS_WINDOW (boxes_kbd_shortcuts_window_get_type ())
#define BOXES_KBD_SHORTCUTS_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_KBD_SHORTCUTS_WINDOW, BoxesKbdShortcutsWindow))
#define BOXES_KBD_SHORTCUTS_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_KBD_SHORTCUTS_WINDOW, BoxesKbdShortcutsWindowClass))
#define BOXES_IS_KBD_SHORTCUTS_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_KBD_SHORTCUTS_WINDOW))
#define BOXES_IS_KBD_SHORTCUTS_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_KBD_SHORTCUTS_WINDOW))
#define BOXES_KBD_SHORTCUTS_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_KBD_SHORTCUTS_WINDOW, BoxesKbdShortcutsWindowClass))

typedef struct _BoxesKbdShortcutsWindow BoxesKbdShortcutsWindow;
typedef struct _BoxesKbdShortcutsWindowClass BoxesKbdShortcutsWindowClass;
typedef struct _BoxesNotificationbarPrivate BoxesNotificationbarPrivate;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;
typedef struct _BoxesCollectionPrivate BoxesCollectionPrivate;
#define _g_free0(var) (var = (g_free (var), NULL))
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
typedef struct _Block11Data Block11Data;

#define BOXES_MACHINE_TYPE_MACHINE_STATE (boxes_machine_machine_state_get_type ())
typedef struct _BoxesWizardWindowPrivate BoxesWizardWindowPrivate;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_WIZARD_TOOLBAR (boxes_wizard_toolbar_get_type ())
#define BOXES_WIZARD_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_TOOLBAR, BoxesWizardToolbar))
#define BOXES_WIZARD_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_TOOLBAR, BoxesWizardToolbarClass))
#define BOXES_IS_WIZARD_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_TOOLBAR))
#define BOXES_IS_WIZARD_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_TOOLBAR))
#define BOXES_WIZARD_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_TOOLBAR, BoxesWizardToolbarClass))

typedef struct _BoxesWizardToolbar BoxesWizardToolbar;
typedef struct _BoxesWizardToolbarClass BoxesWizardToolbarClass;
typedef struct _BoxesPropertiesWindowPrivate BoxesPropertiesWindowPrivate;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_TROUBLESHOOT_LOG (boxes_troubleshoot_log_get_type ())
#define BOXES_TROUBLESHOOT_LOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TROUBLESHOOT_LOG, BoxesTroubleshootLog))
#define BOXES_TROUBLESHOOT_LOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TROUBLESHOOT_LOG, BoxesTroubleshootLogClass))
#define BOXES_IS_TROUBLESHOOT_LOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TROUBLESHOOT_LOG))
#define BOXES_IS_TROUBLESHOOT_LOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TROUBLESHOOT_LOG))
#define BOXES_TROUBLESHOOT_LOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TROUBLESHOOT_LOG, BoxesTroubleshootLogClass))

typedef struct _BoxesTroubleshootLog BoxesTroubleshootLog;
typedef struct _BoxesTroubleshootLogClass BoxesTroubleshootLogClass;

#define BOXES_TYPE_PROPERTIES_TOOLBAR (boxes_properties_toolbar_get_type ())
#define BOXES_PROPERTIES_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES_TOOLBAR, BoxesPropertiesToolbar))
#define BOXES_PROPERTIES_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES_TOOLBAR, BoxesPropertiesToolbarClass))
#define BOXES_IS_PROPERTIES_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES_TOOLBAR))
#define BOXES_IS_PROPERTIES_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES_TOOLBAR))
#define BOXES_PROPERTIES_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES_TOOLBAR, BoxesPropertiesToolbarClass))

typedef struct _BoxesPropertiesToolbar BoxesPropertiesToolbar;
typedef struct _BoxesPropertiesToolbarClass BoxesPropertiesToolbarClass;

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesAppWindow {
	GtkApplicationWindow parent_instance;
	BoxesAppWindowPrivate * priv;
	BoxesWizardWindow* wizard_window;
	BoxesPropertiesWindow* props_window;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesSelectionbar* selectionbar;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	GtkStack* below_bin;
	GSettings* settings;
};

struct _BoxesAppWindowClass {
	GtkApplicationWindowClass parent_class;
};

typedef enum  {
	BOXES_APP_WINDOW_VIEW_TYPE_ICON = 1,
	BOXES_APP_WINDOW_VIEW_TYPE_LIST = 2
} BoxesAppWindowViewType;

typedef enum  {
	BOXES_SELECTION_CRITERIA_ALL,
	BOXES_SELECTION_CRITERIA_NONE,
	BOXES_SELECTION_CRITERIA_RUNNING
} BoxesSelectionCriteria;

struct _BoxesICollectionViewIface {
	GTypeInterface parent_iface;
	void (*add_item) (BoxesICollectionView* self, BoxesCollectionItem* item);
	void (*remove_item) (BoxesICollectionView* self, BoxesCollectionItem* item);
	GList* (*get_selected_items) (BoxesICollectionView* self);
	void (*activate_first_item) (BoxesICollectionView* self);
	void (*select_by_criteria) (BoxesICollectionView* self, BoxesSelectionCriteria criteria);
	BoxesCollectionFilter* (*get_filter) (BoxesICollectionView* self);
	void (*set_filter) (BoxesICollectionView* self, BoxesCollectionFilter* value);
};

struct _BoxesAppWindowPrivate {
	BoxesUIState _previous_ui_state;
	BoxesUIState _ui_state;
	BoxesCollectionItem* _current_item;
	GBinding* status_bind;
	gulong got_error_id;
	gulong machine_state_notify_id;
	gulong machine_deleted_notify_id;
	gboolean _selection_mode;
	BoxesIconView* icon_view;
	BoxesListView* list_view;
	BoxesAppWindowViewType _view_type;
	BoxesICollectionView** views;
	gint views_length1;
	gint _views_size_;
	BoxesNotificationbar* _notificationbar;
	guint configure_id;
	GtkWindowGroup* group;
};

struct _BoxesNotificationbar {
	GtkGrid parent_instance;
	BoxesNotificationbarPrivate * priv;
	BoxesSearchbar* searchbar;
};

struct _BoxesNotificationbarClass {
	GtkGridClass parent_class;
};

struct _BoxesApp {
	GtkApplication parent_instance;
	BoxesAppPrivate * priv;
	BoxesCollection* collection;
	BoxesAsyncLauncher* async_launcher;
};

struct _BoxesAppClass {
	GtkApplicationClass parent_class;
};

struct _BoxesCollection {
	GObject parent_instance;
	BoxesCollectionPrivate * priv;
	GPtrArray* items;
};

struct _BoxesCollectionClass {
	GObjectClass parent_class;
};

struct _Block11Data {
	int _ref_count_;
	BoxesAppWindow* self;
	gchar* text;
};

typedef enum  {
	BOXES_MACHINE_MACHINE_STATE_UNKNOWN,
	BOXES_MACHINE_MACHINE_STATE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_RUNNING,
	BOXES_MACHINE_MACHINE_STATE_PAUSED,
	BOXES_MACHINE_MACHINE_STATE_SAVED,
	BOXES_MACHINE_MACHINE_STATE_SLEEPING
} BoxesMachineMachineState;

struct _BoxesWizardWindow {
	GtkWindow parent_instance;
	BoxesWizardWindowPrivate * priv;
	GtkStack* view;
	BoxesWizard* wizard;
	GtkGrid* customization_grid;
	GtkFileChooserWidget* file_chooser;
	BoxesWizardToolbar* topbar;
	BoxesNotificationbar* notificationbar;
};

struct _BoxesWizardWindowClass {
	GtkWindowClass parent_class;
};

struct _BoxesPropertiesWindow {
	GtkWindow parent_instance;
	BoxesPropertiesWindowPrivate * priv;
	GtkStack* view;
	BoxesProperties* properties;
	BoxesTroubleshootLog* troubleshoot_log;
	GtkFileChooserWidget* file_chooser;
	BoxesPropertiesToolbar* topbar;
	BoxesNotificationbar* notificationbar;
};

struct _BoxesPropertiesWindowClass {
	GtkWindowClass parent_class;
};


static gpointer boxes_app_window_parent_class = NULL;
extern BoxesApp* boxes_app_app;
static BoxesUIIface* boxes_app_window_boxes_ui_parent_iface = NULL;

GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_app_window_get_type (void) G_GNUC_CONST;
GType boxes_wizard_window_get_type (void) G_GNUC_CONST;
GType boxes_properties_window_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_icon_view_get_type (void) G_GNUC_CONST;
GType boxes_list_view_get_type (void) G_GNUC_CONST;
GType boxes_app_window_view_type_get_type (void) G_GNUC_CONST;
GType boxes_selection_criteria_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
GType boxes_icollection_view_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
#define BOXES_APP_WINDOW_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_APP_WINDOW, BoxesAppWindowPrivate))
enum  {
	BOXES_APP_WINDOW_DUMMY_PROPERTY,
	BOXES_APP_WINDOW_PREVIOUS_UI_STATE,
	BOXES_APP_WINDOW_UI_STATE,
	BOXES_APP_WINDOW_CURRENT_ITEM,
	BOXES_APP_WINDOW_FULLSCREENED,
	BOXES_APP_WINDOW_SELECTION_MODE,
	BOXES_APP_WINDOW_NOTIFICATIONBAR,
	BOXES_APP_WINDOW_VIEW_TYPE,
	BOXES_APP_WINDOW_VIEW
};
#define BOXES_APP_WINDOW_TRANSITION_DURATION ((guint) 400)
#define BOXES_APP_WINDOW_configure_id_timeout ((guint) 100)
BoxesAppWindow* boxes_app_window_new (GtkApplication* app);
BoxesAppWindow* boxes_app_window_construct (GType object_type, GtkApplication* app);
static void boxes_app_window_ui_state_changed (BoxesAppWindow* self);
static void _boxes_app_window_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
GtkCssProvider* boxes_load_css (const gchar* css);
static gint _variant_get1 (GVariant* value);
static gint _variant_get2 (GVariant* value);
static gint _variant_get3 (GVariant* value);
static gint _variant_get4 (GVariant* value);
static void __lambda215_ (BoxesAppWindow* self);
GType boxes_kbd_shortcuts_window_get_type (void) G_GNUC_CONST;
BoxesKbdShortcutsWindow* boxes_kbd_shortcuts_window_new (void);
BoxesKbdShortcutsWindow* boxes_kbd_shortcuts_window_construct (GType object_type);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
static void ___lambda215__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self);
void boxes_app_window_setup_ui (BoxesAppWindow* self);
void boxes_topbar_setup_ui (BoxesTopbar* self, BoxesAppWindow* window);
void boxes_display_page_setup_ui (BoxesDisplayPage* self, BoxesAppWindow* window);
void boxes_icon_view_setup_ui (BoxesIconView* self, BoxesAppWindow* window);
void boxes_list_view_setup_ui (BoxesListView* self, BoxesAppWindow* window);
void boxes_selectionbar_setup_ui (BoxesSelectionbar* self, BoxesAppWindow* window);
void boxes_searchbar_setup_ui (BoxesSearchbar* self, BoxesAppWindow* window);
void boxes_empty_boxes_setup_ui (BoxesEmptyBoxes* self, BoxesAppWindow* window);
BoxesNotificationbar* boxes_app_window_get_notificationbar (BoxesAppWindow* self);
BoxesWizardWindow* boxes_wizard_window_new (BoxesAppWindow* app_window);
BoxesWizardWindow* boxes_wizard_window_construct (GType object_type, BoxesAppWindow* app_window);
BoxesPropertiesWindow* boxes_properties_window_new (BoxesAppWindow* app_window);
BoxesPropertiesWindow* boxes_properties_window_construct (GType object_type, BoxesAppWindow* app_window);
static void boxes_app_window_save_window_geometry (BoxesAppWindow* self);
static gboolean boxes_app_window_get_maximized (BoxesAppWindow* self);
static GVariant* _variant_new5 (gint* value, gint value_length1);
static GVariant* _variant_new6 (gint* value, gint value_length1);
void boxes_ui_set_state (BoxesUI* self, BoxesUIState new_state);
GType boxes_machine_get_type (void) G_GNUC_CONST;
BoxesCollectionItem* boxes_app_window_get_current_item (BoxesAppWindow* self);
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
BoxesICollectionView* boxes_app_window_get_view (BoxesAppWindow* self);
void boxes_app_window_set_fullscreened (BoxesAppWindow* self, gboolean value);
void boxes_app_window_foreach_view (BoxesAppWindow* self, GFunc func, void* func_target);
static void ___lambda93_ (BoxesAppWindow* self, BoxesICollectionView* view);
static void ____lambda93__gfunc (gconstpointer data, gpointer self);
void boxes_topbar_set_status (BoxesTopbar* self, const gchar* value);
GCancellable* boxes_machine_get_connecting_cancellable (BoxesMachine* self);
void boxes_machine_schedule_autosave (BoxesMachine* self);
void boxes_machine_unschedule_autosave (BoxesMachine* self);
const gchar* boxes_ui_state_to_string (BoxesUIState self);
BoxesAppWindow* boxes_machine_get_window (BoxesMachine* self);
void boxes_app_window_show_properties (BoxesAppWindow* self);
gboolean boxes_app_window_get_selection_mode (BoxesAppWindow* self);
void boxes_app_window_set_selection_mode (BoxesAppWindow* self, gboolean value);
GList* boxes_icollection_view_get_selected_items (BoxesICollectionView* self);
void boxes_app_window_set_current_item (BoxesAppWindow* self, BoxesCollectionItem* value);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
void boxes_app_window_connect_to (BoxesAppWindow* self, BoxesMachine* machine);
void boxes_machine_set_window (BoxesMachine* self, BoxesAppWindow* value);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
static void __lambda75_ (BoxesAppWindow* self, const gchar* message);
GdNotification* boxes_notificationbar_display_error (BoxesNotificationbar* self, const gchar* message, gint timeout);
#define BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT 6
static void ___lambda75__boxes_machine_got_error (BoxesMachine* _sender, const gchar* message, gpointer self);
void boxes_app_window_select_item (BoxesAppWindow* self, BoxesCollectionItem* item);
BoxesAppWindow* boxes_app_get_main_window (BoxesApp* self);
void boxes_app_window_filter (BoxesAppWindow* self, const gchar* text);
static Block11Data* block11_data_ref (Block11Data* _data11_);
static void block11_data_unref (void * _userdata_);
static void __lambda17_ (Block11Data* _data11_, BoxesICollectionView* view);
BoxesCollectionFilter* boxes_icollection_view_get_filter (BoxesICollectionView* self);
void boxes_collection_filter_set_text (BoxesCollectionFilter* self, const gchar* value);
static void ___lambda17__gfunc (gconstpointer data, gpointer self);
gboolean boxes_app_window_on_key_pressed (BoxesAppWindow* self, GtkWidget* widget, GdkEventKey* event);
gboolean boxes_app_window_get_fullscreened (BoxesAppWindow* self);
gboolean boxes_app_quit_app (BoxesApp* self);
void boxes_topbar_click_new_button (BoxesTopbar* self);
void boxes_topbar_click_search_button (BoxesTopbar* self);
void boxes_topbar_click_back_button (BoxesTopbar* self);
void boxes_topbar_click_cancel_button (BoxesTopbar* self);
static gboolean _boxes_app_window_on_key_pressed_gtk_widget_key_press_event (GtkWidget* _sender, GdkEventKey* event, gpointer self);
static gboolean boxes_app_window_on_configure_event (BoxesAppWindow* self);
static gboolean __lambda216_ (BoxesAppWindow* self);
static gboolean ___lambda216__gsource_func (gpointer self);
static gboolean _boxes_app_window_on_configure_event_gtk_widget_configure_event (GtkWidget* _sender, GdkEventConfigure* event, gpointer self);
static gboolean boxes_app_window_on_window_state_event (BoxesAppWindow* self, GdkEventWindowState* event);
static gboolean _boxes_app_window_on_window_state_event_gtk_widget_window_state_event (GtkWidget* _sender, GdkEventWindowState* event, gpointer self);
static gboolean boxes_app_window_on_delete_event (BoxesAppWindow* self);
gboolean boxes_app_remove_window (BoxesApp* self, BoxesAppWindow* window);
static gboolean _boxes_app_window_on_delete_event_gtk_widget_delete_event (GtkWidget* _sender, GdkEventAny* event, gpointer self);
static void boxes_app_window_on_machine_state_notify (BoxesAppWindow* self);
GType boxes_machine_machine_state_get_type (void) G_GNUC_CONST;
BoxesMachineMachineState boxes_machine_get_state (BoxesMachine* self);
static void boxes_app_window_on_machine_deleted_notify (BoxesAppWindow* self);
gboolean boxes_machine_get_deleted (BoxesMachine* self);
static void _boxes_app_window_on_machine_state_notify_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _boxes_app_window_on_machine_deleted_notify_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_wizard_toolbar_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_troubleshoot_log_get_type (void) G_GNUC_CONST;
GType boxes_properties_toolbar_get_type (void) G_GNUC_CONST;
BoxesAppWindowViewType boxes_app_window_get_view_type (BoxesAppWindow* self);
void boxes_app_window_set_view_type (BoxesAppWindow* self, BoxesAppWindowViewType value);
static void boxes_app_window_finalize (GObject* obj);
BoxesUIState boxes_ui_get_previous_ui_state (BoxesUI* self);
static void _vala_boxes_app_window_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
void boxes_ui_set_previous_ui_state (BoxesUI* self, BoxesUIState value);
void boxes_ui_set_ui_state (BoxesUI* self, BoxesUIState value);
static void _vala_boxes_app_window_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


GType boxes_app_window_view_type_get_type (void) {
	static volatile gsize boxes_app_window_view_type_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_app_window_view_type_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_APP_WINDOW_VIEW_TYPE_ICON, "BOXES_APP_WINDOW_VIEW_TYPE_ICON", "icon"}, {BOXES_APP_WINDOW_VIEW_TYPE_LIST, "BOXES_APP_WINDOW_VIEW_TYPE_LIST", "list"}, {0, NULL, NULL}};
		GType boxes_app_window_view_type_type_id;
		boxes_app_window_view_type_type_id = g_enum_register_static ("BoxesAppWindowViewType", values);
		g_once_init_leave (&boxes_app_window_view_type_type_id__volatile, boxes_app_window_view_type_type_id);
	}
	return boxes_app_window_view_type_type_id__volatile;
}


static void _boxes_app_window_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	boxes_app_window_ui_state_changed ((BoxesAppWindow*) self);
#line 593 "app-window.c"
}


static gint _variant_get1 (GVariant* value) {
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	return g_variant_get_int32 (value);
#line 600 "app-window.c"
}


static gint _variant_get2 (GVariant* value) {
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	return g_variant_get_int32 (value);
#line 607 "app-window.c"
}


static gint _variant_get3 (GVariant* value) {
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	return g_variant_get_int32 (value);
#line 614 "app-window.c"
}


static gint _variant_get4 (GVariant* value) {
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	return g_variant_get_int32 (value);
#line 621 "app-window.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	return self ? g_object_ref (self) : NULL;
#line 628 "app-window.c"
}


static void __lambda215_ (BoxesAppWindow* self) {
	BoxesKbdShortcutsWindow* window = NULL;
	BoxesKbdShortcutsWindow* _tmp0_ = NULL;
	BoxesUIState _tmp1_ = 0;
	BoxesUIState _tmp2_ = 0;
	BoxesKbdShortcutsWindow* _tmp13_ = NULL;
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp0_ = boxes_kbd_shortcuts_window_new ();
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_object_ref_sink (_tmp0_);
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	window = _tmp0_;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp1_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp2_ = _tmp1_;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	if (_tmp2_ == BOXES_UI_STATE_COLLECTION) {
#line 650 "app-window.c"
		BoxesKbdShortcutsWindow* _tmp3_ = NULL;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp3_ = window;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		g_object_set ((GtkShortcutsWindow*) _tmp3_, "view-name", "overview", NULL);
#line 656 "app-window.c"
	} else {
		gboolean _tmp4_ = FALSE;
		BoxesUIState _tmp5_ = 0;
		BoxesUIState _tmp6_ = 0;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp5_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp6_ = _tmp5_;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		if (_tmp6_ == BOXES_UI_STATE_WIZARD) {
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp4_ = TRUE;
#line 669 "app-window.c"
		} else {
			BoxesUIState _tmp7_ = 0;
			BoxesUIState _tmp8_ = 0;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp7_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp8_ = _tmp7_;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp4_ = _tmp8_ == BOXES_UI_STATE_PROPERTIES;
#line 679 "app-window.c"
		}
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		if (_tmp4_) {
#line 683 "app-window.c"
			BoxesKbdShortcutsWindow* _tmp9_ = NULL;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp9_ = window;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			g_object_set ((GtkShortcutsWindow*) _tmp9_, "view-name", "wizard", NULL);
#line 689 "app-window.c"
		} else {
			BoxesUIState _tmp10_ = 0;
			BoxesUIState _tmp11_ = 0;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp10_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp11_ = _tmp10_;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			if (_tmp11_ == BOXES_UI_STATE_DISPLAY) {
#line 699 "app-window.c"
				BoxesKbdShortcutsWindow* _tmp12_ = NULL;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				_tmp12_ = window;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				g_object_set ((GtkShortcutsWindow*) _tmp12_, "view-name", "display", NULL);
#line 705 "app-window.c"
			}
		}
	}
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp13_ = window;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	gtk_widget_show ((GtkWidget*) _tmp13_);
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (window);
#line 715 "app-window.c"
}


static void ___lambda215__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self) {
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	__lambda215_ ((BoxesAppWindow*) self);
#line 722 "app-window.c"
}


BoxesAppWindow* boxes_app_window_construct (GType object_type, GtkApplication* app) {
	BoxesAppWindow * self = NULL;
	GtkApplication* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	GSettings* _tmp2_ = NULL;
	GtkSettings* _tmp3_ = NULL;
	GtkCssProvider* provider = NULL;
	GtkCssProvider* _tmp4_ = NULL;
	GdkScreen* _tmp5_ = NULL;
	GtkCssProvider* _tmp6_ = NULL;
	GVariant* size = NULL;
	GSettings* _tmp7_ = NULL;
	GVariant* _tmp8_ = NULL;
	GVariant* _tmp9_ = NULL;
	gsize _tmp10_ = 0UL;
	GSettings* _tmp23_ = NULL;
	gboolean _tmp24_ = FALSE;
	GVariant* position = NULL;
	GSettings* _tmp25_ = NULL;
	GVariant* _tmp26_ = NULL;
	GVariant* _tmp27_ = NULL;
	gsize _tmp28_ = 0UL;
	BoxesIconView* _tmp41_ = NULL;
	BoxesICollectionView* _tmp42_ = NULL;
	BoxesListView* _tmp43_ = NULL;
	BoxesICollectionView* _tmp44_ = NULL;
	BoxesICollectionView** _tmp45_ = NULL;
	GSimpleAction* action = NULL;
	GSimpleAction* _tmp46_ = NULL;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_val_if_fail (app != NULL, NULL);
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp0_ = app;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp1_ = _ ("Boxes");
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	self = (BoxesAppWindow*) g_object_new (object_type, "application", _tmp0_, "title", _tmp1_, "show-menubar", FALSE, NULL);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp2_ = g_settings_new ("org.gnome.boxes");
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->settings);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	self->settings = _tmp2_;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_signal_connect_object ((GObject*) self, "notify::ui-state", (GCallback) _boxes_app_window_ui_state_changed_g_object_notify, self, 0);
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	gtk_window_set_default_icon_name ("gnome-boxes");
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp3_ = gtk_settings_get_default ();
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_object_set (_tmp3_, "gtk-application-prefer-dark-theme", TRUE, NULL);
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp4_ = boxes_load_css ("gtk-style.css");
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	provider = _tmp4_;
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp5_ = gdk_screen_get_default ();
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp6_ = provider;
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	gtk_style_context_add_provider_for_screen (_tmp5_, (GtkStyleProvider*) _tmp6_, (guint) 600);
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp7_ = self->settings;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp8_ = g_settings_get_value (_tmp7_, "window-size");
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	size = _tmp8_;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp9_ = size;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp10_ = g_variant_n_children (_tmp9_);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	if (_tmp10_ == ((gsize) 2)) {
#line 799 "app-window.c"
		gint width = 0;
		GVariant* _tmp11_ = NULL;
		GVariant* _tmp12_ = NULL;
		GVariant* _tmp13_ = NULL;
		gint _tmp14_ = 0;
		gint _tmp15_ = 0;
		gint height = 0;
		GVariant* _tmp16_ = NULL;
		GVariant* _tmp17_ = NULL;
		GVariant* _tmp18_ = NULL;
		gint _tmp19_ = 0;
		gint _tmp20_ = 0;
		gint _tmp21_ = 0;
		gint _tmp22_ = 0;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp11_ = size;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp12_ = g_variant_get_child_value (_tmp11_, (gsize) 0);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp13_ = _tmp12_;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp14_ = _variant_get1 (_tmp13_);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp15_ = _tmp14_;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_g_variant_unref0 (_tmp13_);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		width = _tmp15_;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp16_ = size;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp17_ = g_variant_get_child_value (_tmp16_, (gsize) 1);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp18_ = _tmp17_;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp19_ = _variant_get2 (_tmp18_);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp20_ = _tmp19_;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_g_variant_unref0 (_tmp18_);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		height = _tmp20_;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp21_ = width;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp22_ = height;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		gtk_window_set_default_size ((GtkWindow*) self, _tmp21_, _tmp22_);
#line 848 "app-window.c"
	}
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp23_ = self->settings;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp24_ = g_settings_get_boolean (_tmp23_, "window-maximized");
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	if (_tmp24_) {
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		gtk_window_maximize ((GtkWindow*) self);
#line 858 "app-window.c"
	}
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp25_ = self->settings;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp26_ = g_settings_get_value (_tmp25_, "window-position");
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	position = _tmp26_;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp27_ = position;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp28_ = g_variant_n_children (_tmp27_);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	if (_tmp28_ == ((gsize) 2)) {
#line 872 "app-window.c"
		gint x = 0;
		GVariant* _tmp29_ = NULL;
		GVariant* _tmp30_ = NULL;
		GVariant* _tmp31_ = NULL;
		gint _tmp32_ = 0;
		gint _tmp33_ = 0;
		gint y = 0;
		GVariant* _tmp34_ = NULL;
		GVariant* _tmp35_ = NULL;
		GVariant* _tmp36_ = NULL;
		gint _tmp37_ = 0;
		gint _tmp38_ = 0;
		gint _tmp39_ = 0;
		gint _tmp40_ = 0;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp29_ = position;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp30_ = g_variant_get_child_value (_tmp29_, (gsize) 0);
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp31_ = _tmp30_;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp32_ = _variant_get3 (_tmp31_);
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp33_ = _tmp32_;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_g_variant_unref0 (_tmp31_);
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		x = _tmp33_;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp34_ = position;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp35_ = g_variant_get_child_value (_tmp34_, (gsize) 1);
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp36_ = _tmp35_;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp37_ = _variant_get4 (_tmp36_);
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp38_ = _tmp37_;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_g_variant_unref0 (_tmp36_);
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		y = _tmp38_;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp39_ = x;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp40_ = y;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		gtk_window_move ((GtkWindow*) self, _tmp39_, _tmp40_);
#line 921 "app-window.c"
	}
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp41_ = self->priv->icon_view;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp42_ = _g_object_ref0 ((BoxesICollectionView*) _tmp41_);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp43_ = self->priv->list_view;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp44_ = _g_object_ref0 ((BoxesICollectionView*) _tmp43_);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp45_ = g_new0 (BoxesICollectionView*, 2 + 1);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp45_[0] = _tmp42_;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp45_[1] = _tmp44_;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	self->priv->views = (_vala_array_free (self->priv->views, self->priv->views_length1, (GDestroyNotify) g_object_unref), NULL);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	self->priv->views = _tmp45_;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	self->priv->views_length1 = 2;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	self->priv->_views_size_ = self->priv->views_length1;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp46_ = g_simple_action_new ("kbd-shortcuts", NULL);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	action = _tmp46_;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_signal_connect_object (action, "activate", (GCallback) ___lambda215__g_simple_action_activate, self, 0);
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_action_map_add_action ((GActionMap*) self, (GAction*) action);
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (action);
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_g_variant_unref0 (position);
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_g_variant_unref0 (size);
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (provider);
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	return self;
#line 963 "app-window.c"
}


BoxesAppWindow* boxes_app_window_new (GtkApplication* app) {
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	return boxes_app_window_construct (BOXES_TYPE_APP_WINDOW, app);
#line 970 "app-window.c"
}


void boxes_app_window_setup_ui (BoxesAppWindow* self) {
	BoxesTopbar* _tmp0_ = NULL;
	BoxesDisplayPage* _tmp1_ = NULL;
	BoxesIconView* _tmp2_ = NULL;
	BoxesListView* _tmp3_ = NULL;
	BoxesSelectionbar* _tmp4_ = NULL;
	BoxesSearchbar* _tmp5_ = NULL;
	BoxesEmptyBoxes* _tmp6_ = NULL;
	BoxesNotificationbar* _tmp7_ = NULL;
	BoxesNotificationbar* _tmp8_ = NULL;
	BoxesSearchbar* _tmp9_ = NULL;
	BoxesSearchbar* _tmp10_ = NULL;
	GtkWindowGroup* _tmp11_ = NULL;
	BoxesWizardWindow* _tmp12_ = NULL;
	GtkWindowGroup* _tmp13_ = NULL;
	BoxesWizardWindow* _tmp14_ = NULL;
	BoxesPropertiesWindow* _tmp15_ = NULL;
	GtkWindowGroup* _tmp16_ = NULL;
	BoxesPropertiesWindow* _tmp17_ = NULL;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_if_fail (self != NULL);
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp0_ = self->topbar;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	boxes_topbar_setup_ui (_tmp0_, self);
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp1_ = self->display_page;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	boxes_display_page_setup_ui (_tmp1_, self);
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp2_ = self->priv->icon_view;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	boxes_icon_view_setup_ui (_tmp2_, self);
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp3_ = self->priv->list_view;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	boxes_list_view_setup_ui (_tmp3_, self);
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp4_ = self->selectionbar;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	boxes_selectionbar_setup_ui (_tmp4_, self);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp5_ = self->searchbar;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	boxes_searchbar_setup_ui (_tmp5_, self);
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp6_ = self->empty_boxes;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	boxes_empty_boxes_setup_ui (_tmp6_, self);
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp7_ = boxes_app_window_get_notificationbar (self);
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp8_ = _tmp7_;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp9_ = self->searchbar;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp10_ = _g_object_ref0 (_tmp9_);
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (_tmp8_->searchbar);
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp8_->searchbar = _tmp10_;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp11_ = gtk_window_group_new ();
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->priv->group);
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	self->priv->group = _tmp11_;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp12_ = boxes_wizard_window_new (self);
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_object_ref_sink (_tmp12_);
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->wizard_window);
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	self->wizard_window = _tmp12_;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp13_ = self->priv->group;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp14_ = self->wizard_window;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	gtk_window_group_add_window (_tmp13_, (GtkWindow*) _tmp14_);
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp15_ = boxes_properties_window_new (self);
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_object_ref_sink (_tmp15_);
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->props_window);
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	self->props_window = _tmp15_;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp16_ = self->priv->group;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp17_ = self->props_window;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	gtk_window_group_add_window (_tmp16_, (GtkWindow*) _tmp17_);
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_signal_connect_object ((GObject*) self, "notify::view-type", (GCallback) _boxes_app_window_ui_state_changed_g_object_notify, self, 0);
#line 1071 "app-window.c"
}


static GVariant* _variant_new5 (gint* value, gint value_length1) {
	gint* _tmp9_;
	GVariantBuilder _tmp10_;
	int _tmp11_;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp9_ = value;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_variant_builder_init (&_tmp10_, G_VARIANT_TYPE ("ai"));
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	for (_tmp11_ = 0; _tmp11_ < value_length1; _tmp11_++) {
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		g_variant_builder_add_value (&_tmp10_, g_variant_new_int32 (*_tmp9_));
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp9_++;
#line 1089 "app-window.c"
	}
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	return g_variant_ref_sink (g_variant_builder_end (&_tmp10_));
#line 1093 "app-window.c"
}


static GVariant* _variant_new6 (gint* value, gint value_length1) {
	gint* _tmp20_;
	GVariantBuilder _tmp21_;
	int _tmp22_;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp20_ = value;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_variant_builder_init (&_tmp21_, G_VARIANT_TYPE ("ai"));
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	for (_tmp22_ = 0; _tmp22_ < value_length1; _tmp22_++) {
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		g_variant_builder_add_value (&_tmp21_, g_variant_new_int32 (*_tmp20_));
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp20_++;
#line 1111 "app-window.c"
	}
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	return g_variant_ref_sink (g_variant_builder_end (&_tmp21_));
#line 1115 "app-window.c"
}


static void boxes_app_window_save_window_geometry (BoxesAppWindow* self) {
	gint width = 0;
	gint height = 0;
	gint x = 0;
	gint y = 0;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	gint _tmp2_ = 0;
	gint _tmp3_ = 0;
	GSettings* _tmp4_ = NULL;
	gint _tmp5_ = 0;
	gint _tmp6_ = 0;
	gint* _tmp7_ = NULL;
	gint* _tmp8_ = NULL;
	gint _tmp8__length1 = 0;
	GVariant* _tmp12_ = NULL;
	gint _tmp13_ = 0;
	gint _tmp14_ = 0;
	GSettings* _tmp15_ = NULL;
	gint _tmp16_ = 0;
	gint _tmp17_ = 0;
	gint* _tmp18_ = NULL;
	gint* _tmp19_ = NULL;
	gint _tmp19__length1 = 0;
	GVariant* _tmp23_ = NULL;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_if_fail (self != NULL);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp0_ = boxes_app_window_get_maximized (self);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp1_ = _tmp0_;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	if (_tmp1_) {
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		return;
#line 1154 "app-window.c"
	}
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	gtk_window_get_size ((GtkWindow*) self, &_tmp2_, &_tmp3_);
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	width = _tmp2_;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	height = _tmp3_;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp4_ = self->settings;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp5_ = width;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp6_ = height;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp7_ = g_new0 (gint, 2);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp7_[0] = _tmp5_;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp7_[1] = _tmp6_;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp8_ = _tmp7_;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp8__length1 = 2;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp12_ = _variant_new5 (_tmp8_, 2);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_settings_set_value (_tmp4_, "window-size", _tmp12_);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_g_variant_unref0 (_tmp12_);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp8_ = (g_free (_tmp8_), NULL);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	gtk_window_get_position ((GtkWindow*) self, &_tmp13_, &_tmp14_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	x = _tmp13_;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	y = _tmp14_;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp15_ = self->settings;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp16_ = x;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp17_ = y;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp18_ = g_new0 (gint, 2);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp18_[0] = _tmp16_;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp18_[1] = _tmp17_;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp19_ = _tmp18_;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp19__length1 = 2;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp23_ = _variant_new6 (_tmp19_, 2);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_settings_set_value (_tmp15_, "window-position", _tmp23_);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_g_variant_unref0 (_tmp23_);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp19_ = (g_free (_tmp19_), NULL);
#line 1216 "app-window.c"
}


static gint g_ptr_array_get_length (GPtrArray* self) {
	gint result;
	guint _tmp0_ = 0U;
#line 4803 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, 0);
#line 4803 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp0_ = self->len;
#line 4803 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
	result = (gint) _tmp0_;
#line 4803 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
	return result;
#line 1231 "app-window.c"
}


static void g_ptr_array_set_length (GPtrArray* self, gint value) {
	gint _tmp0_ = 0;
#line 4804 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_if_fail (self != NULL);
#line 4804 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp0_ = value;
#line 4804 "/home/zeenix/jhbuild/share/vala-0.32/vapi/glib-2.0.vapi"
	g_ptr_array_set_size (self, _tmp0_);
#line 1243 "app-window.c"
}


static void ___lambda93_ (BoxesAppWindow* self, BoxesICollectionView* view) {
	BoxesICollectionView* _tmp0_ = NULL;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_if_fail (view != NULL);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp0_ = view;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	gtk_widget_set_visible ((GtkWidget*) _tmp0_, TRUE);
#line 1255 "app-window.c"
}


static void ____lambda93__gfunc (gconstpointer data, gpointer self) {
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	___lambda93_ ((BoxesAppWindow*) self, (BoxesICollectionView*) data);
#line 1262 "app-window.c"
}


static void boxes_app_window_ui_state_changed (BoxesAppWindow* self) {
	BoxesTopbar* _tmp0_ = NULL;
	BoxesUI* _tmp1_ = NULL;
	BoxesIconView* _tmp2_ = NULL;
	BoxesUI* _tmp3_ = NULL;
	BoxesListView* _tmp4_ = NULL;
	BoxesUI* _tmp5_ = NULL;
	BoxesPropertiesWindow* _tmp6_ = NULL;
	BoxesUI* _tmp7_ = NULL;
	BoxesWizardWindow* _tmp8_ = NULL;
	BoxesUI* _tmp9_ = NULL;
	BoxesEmptyBoxes* _tmp10_ = NULL;
	BoxesUI* _tmp11_ = NULL;
	BoxesUI** _tmp12_ = NULL;
	BoxesUIState _tmp17_ = 0;
	BoxesUIState _tmp18_ = 0;
	BoxesMachine* _tmp20_ = NULL;
	BoxesCollectionItem* _tmp21_ = NULL;
	BoxesCollectionItem* _tmp22_ = NULL;
	BoxesMachine* machine = NULL;
	BoxesMachine* _tmp25_ = NULL;
	BoxesUIState _tmp26_ = 0;
	BoxesUIState _tmp27_ = 0;
	gboolean _tmp64_ = FALSE;
	BoxesMachine* _tmp65_ = NULL;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_if_fail (self != NULL);
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp0_ = self->topbar;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp1_ = _g_object_ref0 ((BoxesUI*) _tmp0_);
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp2_ = self->priv->icon_view;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp3_ = _g_object_ref0 ((BoxesUI*) _tmp2_);
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp4_ = self->priv->list_view;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp5_ = _g_object_ref0 ((BoxesUI*) _tmp4_);
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp6_ = self->props_window;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp7_ = _g_object_ref0 ((BoxesUI*) _tmp6_);
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp8_ = self->wizard_window;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp9_ = _g_object_ref0 ((BoxesUI*) _tmp8_);
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp10_ = self->empty_boxes;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp11_ = _g_object_ref0 ((BoxesUI*) _tmp10_);
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp12_ = g_new0 (BoxesUI*, 6 + 1);
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp12_[0] = _tmp1_;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp12_[1] = _tmp3_;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp12_[2] = _tmp5_;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp12_[3] = _tmp7_;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp12_[4] = _tmp9_;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp12_[5] = _tmp11_;
#line 1331 "app-window.c"
	{
		BoxesUI** ui_collection = NULL;
		gint ui_collection_length1 = 0;
		gint _ui_collection_size_ = 0;
		gint ui_it = 0;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		ui_collection = _tmp12_;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		ui_collection_length1 = 6;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		for (ui_it = 0; ui_it < 6; ui_it = ui_it + 1) {
#line 1343 "app-window.c"
			BoxesUI* _tmp13_ = NULL;
			BoxesUI* ui = NULL;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp13_ = _g_object_ref0 (ui_collection[ui_it]);
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			ui = _tmp13_;
#line 1350 "app-window.c"
			{
				BoxesUI* _tmp14_ = NULL;
				BoxesUIState _tmp15_ = 0;
				BoxesUIState _tmp16_ = 0;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				_tmp14_ = ui;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				_tmp15_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				_tmp16_ = _tmp15_;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				boxes_ui_set_state (_tmp14_, _tmp16_);
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				_g_object_unref0 (ui);
#line 1365 "app-window.c"
			}
		}
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		ui_collection = (_vala_array_free (ui_collection, ui_collection_length1, (GDestroyNotify) g_object_unref), NULL);
#line 1370 "app-window.c"
	}
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp17_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp18_ = _tmp17_;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	if (_tmp18_ != BOXES_UI_STATE_COLLECTION) {
#line 1378 "app-window.c"
		BoxesSearchbar* _tmp19_ = NULL;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp19_ = self->searchbar;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		g_object_set ((GtkSearchBar*) _tmp19_, "search-mode-enabled", FALSE, NULL);
#line 1384 "app-window.c"
	}
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp21_ = boxes_app_window_get_current_item (self);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp22_ = _tmp21_;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp22_, BOXES_TYPE_MACHINE)) {
#line 1392 "app-window.c"
		BoxesCollectionItem* _tmp23_ = NULL;
		BoxesCollectionItem* _tmp24_ = NULL;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp23_ = boxes_app_window_get_current_item (self);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp24_ = _tmp23_;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp20_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp24_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp24_) : NULL;
#line 1401 "app-window.c"
	} else {
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp20_ = NULL;
#line 1405 "app-window.c"
	}
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp25_ = _g_object_ref0 (_tmp20_);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	machine = _tmp25_;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp26_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp27_ = _tmp26_;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	switch (_tmp27_) {
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		case BOXES_UI_STATE_COLLECTION:
#line 1419 "app-window.c"
		{
			BoxesApp* _tmp28_ = NULL;
			BoxesCollection* _tmp29_ = NULL;
			GPtrArray* _tmp30_ = NULL;
			gint _tmp31_ = 0;
			gint _tmp32_ = 0;
			GBinding* _tmp38_ = NULL;
			BoxesTopbar* _tmp41_ = NULL;
			const gchar* _tmp42_ = NULL;
			AtkObject* a11y = NULL;
			AtkObject* _tmp43_ = NULL;
			AtkObject* _tmp44_ = NULL;
			AtkObject* _tmp45_ = NULL;
			const gchar* _tmp46_ = NULL;
			BoxesMachine* _tmp47_ = NULL;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp28_ = boxes_app_app;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp29_ = _tmp28_->collection;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp30_ = _tmp29_->items;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp31_ = g_ptr_array_get_length (_tmp30_);
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp32_ = _tmp31_;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			if (_tmp32_ != 0) {
#line 1447 "app-window.c"
				GtkStack* _tmp33_ = NULL;
				BoxesICollectionView* _tmp34_ = NULL;
				BoxesICollectionView* _tmp35_ = NULL;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				_tmp33_ = self->below_bin;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				_tmp34_ = boxes_app_window_get_view (self);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				_tmp35_ = _tmp34_;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				gtk_stack_set_visible_child (_tmp33_, (GtkWidget*) _tmp35_);
#line 1459 "app-window.c"
			} else {
				GtkStack* _tmp36_ = NULL;
				BoxesEmptyBoxes* _tmp37_ = NULL;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				_tmp36_ = self->below_bin;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				_tmp37_ = self->empty_boxes;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				gtk_stack_set_visible_child (_tmp36_, (GtkWidget*) _tmp37_);
#line 1469 "app-window.c"
			}
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			boxes_app_window_set_fullscreened (self, FALSE);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			boxes_app_window_foreach_view (self, ____lambda93__gfunc, self);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp38_ = self->priv->status_bind;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			if (_tmp38_ != NULL) {
#line 1479 "app-window.c"
				GBinding* _tmp39_ = NULL;
				GBinding* _tmp40_ = NULL;
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				_tmp39_ = self->priv->status_bind;
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				_tmp40_ = _g_object_ref0 (_tmp39_);
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				g_binding_unbind (_tmp40_);
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				_g_object_unref0 (self->priv->status_bind);
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				self->priv->status_bind = NULL;
#line 1492 "app-window.c"
			}
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp41_ = self->topbar;
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp42_ = _ ("Boxes");
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			boxes_topbar_set_status (_tmp41_, _tmp42_);
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp43_ = gtk_widget_get_accessible ((GtkWidget*) self);
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp44_ = _g_object_ref0 (_tmp43_);
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			a11y = _tmp44_;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp45_ = a11y;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp46_ = _ ("Boxes");
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			g_object_set (_tmp45_, "accessible-name", _tmp46_, NULL);
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp47_ = machine;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			if (_tmp47_ != NULL) {
#line 1516 "app-window.c"
				gulong _tmp48_ = 0UL;
				BoxesMachine* _tmp51_ = NULL;
				GCancellable* _tmp52_ = NULL;
				GCancellable* _tmp53_ = NULL;
				BoxesMachine* _tmp54_ = NULL;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				_tmp48_ = self->priv->got_error_id;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				if (_tmp48_ != ((gulong) 0)) {
#line 1526 "app-window.c"
					BoxesMachine* _tmp49_ = NULL;
					gulong _tmp50_ = 0UL;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
					_tmp49_ = machine;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
					_tmp50_ = self->priv->got_error_id;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
					g_signal_handler_disconnect ((GObject*) _tmp49_, _tmp50_);
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
					self->priv->got_error_id = (gulong) 0;
#line 1537 "app-window.c"
				}
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				_tmp51_ = machine;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				_tmp52_ = boxes_machine_get_connecting_cancellable (_tmp51_);
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				_tmp53_ = _tmp52_;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				g_cancellable_cancel (_tmp53_);
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				_tmp54_ = machine;
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				boxes_machine_schedule_autosave (_tmp54_);
#line 1551 "app-window.c"
			}
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_g_object_unref0 (a11y);
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			break;
#line 1557 "app-window.c"
		}
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		case BOXES_UI_STATE_CREDS:
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		case BOXES_UI_STATE_DISPLAY:
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		case BOXES_UI_STATE_WIZARD:
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		case BOXES_UI_STATE_PROPERTIES:
#line 1567 "app-window.c"
		{
			BoxesCollectionItem* _tmp55_ = NULL;
			BoxesCollectionItem* _tmp56_ = NULL;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp55_ = boxes_app_window_get_current_item (self);
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp56_ = _tmp55_;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			if (_tmp56_ != NULL) {
#line 1577 "app-window.c"
				BoxesCollectionItem* _tmp57_ = NULL;
				BoxesCollectionItem* _tmp58_ = NULL;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				_tmp57_ = boxes_app_window_get_current_item (self);
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				_tmp58_ = _tmp57_;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				boxes_machine_unschedule_autosave (G_TYPE_CHECK_INSTANCE_TYPE (_tmp58_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp58_) : NULL);
#line 1586 "app-window.c"
			}
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			break;
#line 1590 "app-window.c"
		}
		default:
		{
			BoxesUIState _tmp59_ = 0;
			BoxesUIState _tmp60_ = 0;
			GEnumValue* _tmp61_;
			gchar* _tmp62_ = NULL;
			gchar* _tmp63_ = NULL;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp59_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp60_ = _tmp59_;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp61_ = g_enum_get_value (g_type_class_ref (BOXES_TYPE_UI_STATE), _tmp60_);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp62_ = g_strdup_printf ("Unhandled UI state %s", (_tmp61_ != NULL) ? _tmp61_->value_name : NULL);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp63_ = _tmp62_;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			g_warning ("app-window.vala:270: %s", _tmp63_);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_g_free0 (_tmp63_);
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			break;
#line 1615 "app-window.c"
		}
	}
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp65_ = machine;
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	if (_tmp65_ != NULL) {
#line 1622 "app-window.c"
		BoxesMachine* _tmp66_ = NULL;
		BoxesAppWindow* _tmp67_ = NULL;
		BoxesAppWindow* _tmp68_ = NULL;
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp66_ = machine;
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp67_ = boxes_machine_get_window (_tmp66_);
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp68_ = _tmp67_;
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp64_ = self == _tmp68_;
#line 1634 "app-window.c"
	} else {
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp64_ = FALSE;
#line 1638 "app-window.c"
	}
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	if (_tmp64_) {
#line 1642 "app-window.c"
		BoxesCollectionItem* _tmp69_ = NULL;
		BoxesCollectionItem* _tmp70_ = NULL;
		BoxesUIState _tmp71_ = 0;
		BoxesUIState _tmp72_ = 0;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp69_ = boxes_app_window_get_current_item (self);
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp70_ = _tmp69_;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp71_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp72_ = _tmp71_;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		boxes_ui_set_state ((BoxesUI*) _tmp70_, _tmp72_);
#line 1657 "app-window.c"
	}
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (machine);
#line 1661 "app-window.c"
}


void boxes_app_window_foreach_view (BoxesAppWindow* self, GFunc func, void* func_target) {
	BoxesICollectionView** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_if_fail (self != NULL);
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp0_ = self->priv->views;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp0__length1 = self->priv->views_length1;
#line 1674 "app-window.c"
	{
		BoxesICollectionView** view_collection = NULL;
		gint view_collection_length1 = 0;
		gint _view_collection_size_ = 0;
		gint view_it = 0;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		view_collection = _tmp0_;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		view_collection_length1 = _tmp0__length1;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		for (view_it = 0; view_it < _tmp0__length1; view_it = view_it + 1) {
#line 1686 "app-window.c"
			BoxesICollectionView* _tmp1_ = NULL;
			BoxesICollectionView* view = NULL;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp1_ = _g_object_ref0 (view_collection[view_it]);
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			view = _tmp1_;
#line 1693 "app-window.c"
			{
				GFunc _tmp2_ = NULL;
				void* _tmp2__target = NULL;
				BoxesICollectionView* _tmp3_ = NULL;
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				_tmp2_ = func;
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				_tmp2__target = func_target;
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				_tmp3_ = view;
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				_tmp2_ (_tmp3_, _tmp2__target);
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				_g_object_unref0 (view);
#line 1708 "app-window.c"
			}
		}
	}
}


static void _g_object_unref0_ (gpointer var) {
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 1718 "app-window.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_list_free (self);
#line 1727 "app-window.c"
}


void boxes_app_window_show_properties (BoxesAppWindow* self) {
	BoxesCollectionItem* _tmp0_ = NULL;
	BoxesCollectionItem* _tmp1_ = NULL;
	GList* selected_items = NULL;
	BoxesICollectionView* _tmp7_ = NULL;
	BoxesICollectionView* _tmp8_ = NULL;
	GList* _tmp9_ = NULL;
	gboolean _tmp10_ = FALSE;
	BoxesUIState _tmp11_ = 0;
	BoxesUIState _tmp12_ = 0;
	GList* _tmp15_ = NULL;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_if_fail (self != NULL);
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp0_ = boxes_app_window_get_current_item (self);
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp1_ = _tmp0_;
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	if (_tmp1_ != NULL) {
#line 1750 "app-window.c"
		gboolean _tmp2_ = FALSE;
		BoxesUIState _tmp3_ = 0;
		BoxesUIState _tmp4_ = 0;
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp3_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp4_ = _tmp3_;
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		if (_tmp4_ == BOXES_UI_STATE_COLLECTION) {
#line 1760 "app-window.c"
			gboolean _tmp5_ = FALSE;
			gboolean _tmp6_ = FALSE;
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp5_ = boxes_app_window_get_selection_mode (self);
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp6_ = _tmp5_;
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp2_ = _tmp6_;
#line 1769 "app-window.c"
		} else {
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp2_ = FALSE;
#line 1773 "app-window.c"
		}
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		if (_tmp2_) {
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			boxes_app_window_set_selection_mode (self, FALSE);
#line 1779 "app-window.c"
		}
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		boxes_ui_set_state ((BoxesUI*) self, BOXES_UI_STATE_PROPERTIES);
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		return;
#line 1785 "app-window.c"
	}
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp7_ = boxes_app_window_get_view (self);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp8_ = _tmp7_;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp9_ = boxes_icollection_view_get_selected_items (_tmp8_);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	selected_items = _tmp9_;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp11_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp12_ = _tmp11_;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	if (_tmp12_ == BOXES_UI_STATE_COLLECTION) {
#line 1801 "app-window.c"
		gboolean _tmp13_ = FALSE;
		gboolean _tmp14_ = FALSE;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp13_ = boxes_app_window_get_selection_mode (self);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp14_ = _tmp13_;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp10_ = _tmp14_;
#line 1810 "app-window.c"
	} else {
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp10_ = FALSE;
#line 1814 "app-window.c"
	}
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	if (_tmp10_) {
#line 295 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		boxes_app_window_set_selection_mode (self, FALSE);
#line 1820 "app-window.c"
	}
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp15_ = selected_items;
#line 1824 "app-window.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		item_collection = _tmp15_;
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 1832 "app-window.c"
			BoxesCollectionItem* _tmp16_ = NULL;
			BoxesCollectionItem* item = NULL;
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp16_ = _g_object_ref0 ((BoxesCollectionItem*) item_it->data);
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			item = _tmp16_;
#line 1839 "app-window.c"
			{
				BoxesCollectionItem* _tmp17_ = NULL;
#line 299 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				_tmp17_ = item;
#line 299 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				boxes_app_window_set_current_item (self, _tmp17_);
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				boxes_ui_set_state ((BoxesUI*) self, BOXES_UI_STATE_PROPERTIES);
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				_g_object_unref0 (item);
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				break;
#line 1852 "app-window.c"
			}
		}
	}
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	__g_list_free__g_object_unref0_0 (selected_items);
#line 1858 "app-window.c"
}


static void __lambda75_ (BoxesAppWindow* self, const gchar* message) {
	BoxesNotificationbar* _tmp0_ = NULL;
	BoxesNotificationbar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	GdNotification* _tmp3_ = NULL;
	GdNotification* _tmp4_ = NULL;
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_if_fail (message != NULL);
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp0_ = boxes_app_window_get_notificationbar (self);
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp1_ = _tmp0_;
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp2_ = message;
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp3_ = boxes_notificationbar_display_error (_tmp1_, _tmp2_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp4_ = _tmp3_;
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (_tmp4_);
#line 1882 "app-window.c"
}


static void ___lambda75__boxes_machine_got_error (BoxesMachine* _sender, const gchar* message, gpointer self) {
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	__lambda75_ ((BoxesAppWindow*) self, message);
#line 1889 "app-window.c"
}


void boxes_app_window_connect_to (BoxesAppWindow* self, BoxesMachine* machine) {
	BoxesMachine* _tmp0_ = NULL;
	BoxesMachine* _tmp1_ = NULL;
	BoxesMachine* _tmp2_ = NULL;
	AtkObject* a11y = NULL;
	AtkObject* _tmp3_ = NULL;
	AtkObject* _tmp4_ = NULL;
	AtkObject* _tmp5_ = NULL;
	BoxesMachine* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	BoxesMachine* _tmp9_ = NULL;
	BoxesTopbar* _tmp10_ = NULL;
	GBinding* _tmp11_ = NULL;
	GBinding* _tmp12_ = NULL;
	BoxesMachine* _tmp13_ = NULL;
	gulong _tmp14_ = 0UL;
	BoxesUIState _tmp15_ = 0;
	BoxesUIState _tmp16_ = 0;
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_if_fail (self != NULL);
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_if_fail (machine != NULL);
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp0_ = machine;
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	boxes_app_window_set_current_item (self, (BoxesCollectionItem*) _tmp0_);
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp1_ = machine;
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	boxes_machine_set_window (_tmp1_, self);
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp2_ = machine;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	boxes_machine_unschedule_autosave (_tmp2_);
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp3_ = gtk_widget_get_accessible ((GtkWidget*) self);
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	a11y = _tmp4_;
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp5_ = a11y;
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp6_ = machine;
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp7_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp6_);
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp8_ = _tmp7_;
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_object_set (_tmp5_, "accessible-name", _tmp8_, NULL);
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp9_ = machine;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp10_ = self->topbar;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp11_ = g_object_bind_property_with_closures ((GObject*) _tmp9_, "status", (GObject*) _tmp10_, "status", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp12_ = _g_object_ref0 (_tmp11_);
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->priv->status_bind);
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	self->priv->status_bind = _tmp12_;
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp13_ = machine;
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp14_ = g_signal_connect_object (_tmp13_, "got-error", (GCallback) ___lambda75__boxes_machine_got_error, self, 0);
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	self->priv->got_error_id = _tmp14_;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp15_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp16_ = _tmp15_;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	if (_tmp16_ != BOXES_UI_STATE_CREDS) {
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		boxes_ui_set_state ((BoxesUI*) self, BOXES_UI_STATE_CREDS);
#line 1970 "app-window.c"
	}
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (a11y);
#line 1974 "app-window.c"
}


void boxes_app_window_select_item (BoxesAppWindow* self, BoxesCollectionItem* item) {
	gboolean _tmp0_ = FALSE;
	BoxesUIState _tmp1_ = 0;
	BoxesUIState _tmp2_ = 0;
	BoxesCollectionItem* _tmp5_ = NULL;
	BoxesMachine* machine = NULL;
	BoxesCollectionItem* _tmp6_ = NULL;
	BoxesMachine* _tmp7_ = NULL;
	BoxesMachine* _tmp8_ = NULL;
	BoxesAppWindow* _tmp9_ = NULL;
	BoxesAppWindow* _tmp10_ = NULL;
	BoxesApp* _tmp11_ = NULL;
	BoxesAppWindow* _tmp12_ = NULL;
	BoxesAppWindow* _tmp13_ = NULL;
	BoxesCollectionItem* _tmp17_ = NULL;
	BoxesCollectionItem* _tmp18_ = NULL;
	BoxesCollectionItem* _tmp19_ = NULL;
	BoxesCollectionItem* _tmp21_ = NULL;
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_if_fail (self != NULL);
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_if_fail (item != NULL);
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp1_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp2_ = _tmp1_;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	if (_tmp2_ != BOXES_UI_STATE_COLLECTION) {
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp0_ = TRUE;
#line 2008 "app-window.c"
	} else {
		gboolean _tmp3_ = FALSE;
		gboolean _tmp4_ = FALSE;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp3_ = boxes_app_window_get_selection_mode (self);
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp4_ = _tmp3_;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp0_ = _tmp4_;
#line 2018 "app-window.c"
	}
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	if (_tmp0_) {
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		return;
#line 2024 "app-window.c"
	}
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp5_ = item;
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, BOXES_TYPE_MACHINE));
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp6_ = item;
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp7_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp6_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp6_) : NULL);
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	machine = _tmp7_;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp8_ = machine;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp9_ = boxes_machine_get_window (_tmp8_);
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp10_ = _tmp9_;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp11_ = boxes_app_app;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp12_ = boxes_app_get_main_window (_tmp11_);
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp13_ = _tmp12_;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	if (_tmp10_ != _tmp13_) {
#line 2050 "app-window.c"
		BoxesMachine* _tmp14_ = NULL;
		BoxesAppWindow* _tmp15_ = NULL;
		BoxesAppWindow* _tmp16_ = NULL;
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp14_ = machine;
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp15_ = boxes_machine_get_window (_tmp14_);
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp16_ = _tmp15_;
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		gtk_window_present ((GtkWindow*) _tmp16_);
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_g_object_unref0 (machine);
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		return;
#line 2066 "app-window.c"
	}
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp17_ = item;
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	boxes_app_window_set_current_item (self, _tmp17_);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp18_ = boxes_app_window_get_current_item (self);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp19_ = _tmp18_;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp19_, BOXES_TYPE_MACHINE)) {
#line 2078 "app-window.c"
		BoxesMachine* _tmp20_ = NULL;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp20_ = machine;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		boxes_app_window_connect_to (self, _tmp20_);
#line 2084 "app-window.c"
	} else {
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		g_warning ("app-window.vala:343: unknown item, fix your code");
#line 2088 "app-window.c"
	}
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp21_ = item;
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_signal_emit_by_name (self, "item-selected", _tmp21_);
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (machine);
#line 2096 "app-window.c"
}


static Block11Data* block11_data_ref (Block11Data* _data11_) {
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_atomic_int_inc (&_data11_->_ref_count_);
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	return _data11_;
#line 2105 "app-window.c"
}


static void block11_data_unref (void * _userdata_) {
	Block11Data* _data11_;
	_data11_ = (Block11Data*) _userdata_;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	if (g_atomic_int_dec_and_test (&_data11_->_ref_count_)) {
#line 2114 "app-window.c"
		BoxesAppWindow* self;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		self = _data11_->self;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_g_free0 (_data11_->text);
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_g_object_unref0 (self);
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		g_slice_free (Block11Data, _data11_);
#line 2124 "app-window.c"
	}
}


static void __lambda17_ (Block11Data* _data11_, BoxesICollectionView* view) {
	BoxesAppWindow* self;
	BoxesICollectionView* _tmp0_ = NULL;
	BoxesCollectionFilter* _tmp1_ = NULL;
	BoxesCollectionFilter* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	self = _data11_->self;
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_if_fail (view != NULL);
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp0_ = view;
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp1_ = boxes_icollection_view_get_filter (_tmp0_);
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp2_ = _tmp1_;
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp3_ = _data11_->text;
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	boxes_collection_filter_set_text (_tmp2_, _tmp3_);
#line 2149 "app-window.c"
}


static void ___lambda17__gfunc (gconstpointer data, gpointer self) {
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	__lambda17_ (self, (BoxesICollectionView*) data);
#line 2156 "app-window.c"
}


void boxes_app_window_filter (BoxesAppWindow* self, const gchar* text) {
	Block11Data* _data11_;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_if_fail (self != NULL);
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_if_fail (text != NULL);
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_data11_ = g_slice_new0 (Block11Data);
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_data11_->_ref_count_ = 1;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_data11_->self = g_object_ref (self);
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp0_ = text;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_g_free0 (_data11_->text);
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_data11_->text = _tmp1_;
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	boxes_app_window_foreach_view (self, ___lambda17__gfunc, _data11_);
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	block11_data_unref (_data11_);
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_data11_ = NULL;
#line 2188 "app-window.c"
}


gboolean boxes_app_window_on_key_pressed (BoxesAppWindow* self, GtkWidget* widget, GdkEventKey* event) {
	gboolean result = FALSE;
	GdkModifierType default_modifiers = 0;
	GdkModifierType _tmp0_ = 0;
	GtkTextDirection direction = 0;
	GtkTextDirection _tmp1_ = 0;
	GdkEventKey* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_val_if_fail (widget != NULL, FALSE);
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 354 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp0_ = gtk_accelerator_get_default_mod_mask ();
#line 354 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	default_modifiers = _tmp0_;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp1_ = gtk_widget_get_direction ((GtkWidget*) self);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	direction = _tmp1_;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp2_ = event;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp3_ = _tmp2_->keyval;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	if (_tmp3_ == ((guint) GDK_KEY_F11)) {
#line 2220 "app-window.c"
		gboolean _tmp4_ = FALSE;
		gboolean _tmp5_ = FALSE;
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp4_ = boxes_app_window_get_fullscreened (self);
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp5_ = _tmp4_;
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		boxes_app_window_set_fullscreened (self, !_tmp5_);
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		result = TRUE;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		return result;
#line 2233 "app-window.c"
	} else {
		GdkEventKey* _tmp6_ = NULL;
		guint _tmp7_ = 0U;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp6_ = event;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp7_ = _tmp6_->keyval;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		if (_tmp7_ == ((guint) GDK_KEY_F1)) {
#line 2243 "app-window.c"
			BoxesApp* _tmp8_ = NULL;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp8_ = boxes_app_app;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			g_action_group_activate_action ((GActionGroup*) _tmp8_, "help", NULL);
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			result = TRUE;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			return result;
#line 2253 "app-window.c"
		} else {
			gboolean _tmp9_ = FALSE;
			GdkEventKey* _tmp10_ = NULL;
			guint _tmp11_ = 0U;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp10_ = event;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp11_ = _tmp10_->keyval;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			if (_tmp11_ == ((guint) GDK_KEY_k)) {
#line 2264 "app-window.c"
				GdkEventKey* _tmp12_ = NULL;
				GdkModifierType _tmp13_ = 0;
				GdkModifierType _tmp14_ = 0;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				_tmp12_ = event;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				_tmp13_ = _tmp12_->state;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				_tmp14_ = default_modifiers;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				_tmp9_ = (_tmp13_ & _tmp14_) == GDK_CONTROL_MASK;
#line 2276 "app-window.c"
			} else {
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				_tmp9_ = FALSE;
#line 2280 "app-window.c"
			}
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			if (_tmp9_) {
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				g_action_group_activate_action ((GActionGroup*) self, "kbd-shortcuts", NULL);
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				result = TRUE;
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				return result;
#line 2290 "app-window.c"
			} else {
				gboolean _tmp15_ = FALSE;
				GdkEventKey* _tmp16_ = NULL;
				guint _tmp17_ = 0U;
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				_tmp16_ = event;
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				_tmp17_ = _tmp16_->keyval;
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				if (_tmp17_ == ((guint) GDK_KEY_q)) {
#line 2301 "app-window.c"
					GdkEventKey* _tmp18_ = NULL;
					GdkModifierType _tmp19_ = 0;
					GdkModifierType _tmp20_ = 0;
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
					_tmp18_ = event;
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
					_tmp19_ = _tmp18_->state;
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
					_tmp20_ = default_modifiers;
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
					_tmp15_ = (_tmp19_ & _tmp20_) == GDK_CONTROL_MASK;
#line 2313 "app-window.c"
				} else {
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
					_tmp15_ = FALSE;
#line 2317 "app-window.c"
				}
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
				if (_tmp15_) {
#line 2321 "app-window.c"
					BoxesApp* _tmp21_ = NULL;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
					_tmp21_ = boxes_app_app;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
					boxes_app_quit_app (_tmp21_);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
					result = TRUE;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
					return result;
#line 2331 "app-window.c"
				} else {
					gboolean _tmp22_ = FALSE;
					GdkEventKey* _tmp23_ = NULL;
					guint _tmp24_ = 0U;
#line 375 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
					_tmp23_ = event;
#line 375 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
					_tmp24_ = _tmp23_->keyval;
#line 375 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
					if (_tmp24_ == ((guint) GDK_KEY_n)) {
#line 2342 "app-window.c"
						GdkEventKey* _tmp25_ = NULL;
						GdkModifierType _tmp26_ = 0;
						GdkModifierType _tmp27_ = 0;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
						_tmp25_ = event;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
						_tmp26_ = _tmp25_->state;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
						_tmp27_ = default_modifiers;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
						_tmp22_ = (_tmp26_ & _tmp27_) == GDK_CONTROL_MASK;
#line 2354 "app-window.c"
					} else {
#line 375 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
						_tmp22_ = FALSE;
#line 2358 "app-window.c"
					}
#line 375 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
					if (_tmp22_) {
#line 2362 "app-window.c"
						BoxesTopbar* _tmp28_ = NULL;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
						_tmp28_ = self->topbar;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
						boxes_topbar_click_new_button (_tmp28_);
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
						result = TRUE;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
						return result;
#line 2372 "app-window.c"
					} else {
						gboolean _tmp29_ = FALSE;
						GdkEventKey* _tmp30_ = NULL;
						guint _tmp31_ = 0U;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
						_tmp30_ = event;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
						_tmp31_ = _tmp30_->keyval;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
						if (_tmp31_ == ((guint) GDK_KEY_f)) {
#line 2383 "app-window.c"
							GdkEventKey* _tmp32_ = NULL;
							GdkModifierType _tmp33_ = 0;
							GdkModifierType _tmp34_ = 0;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
							_tmp32_ = event;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
							_tmp33_ = _tmp32_->state;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
							_tmp34_ = default_modifiers;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
							_tmp29_ = (_tmp33_ & _tmp34_) == GDK_CONTROL_MASK;
#line 2395 "app-window.c"
						} else {
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
							_tmp29_ = FALSE;
#line 2399 "app-window.c"
						}
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
						if (_tmp29_) {
#line 2403 "app-window.c"
							BoxesTopbar* _tmp35_ = NULL;
#line 382 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
							_tmp35_ = self->topbar;
#line 382 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
							boxes_topbar_click_search_button (_tmp35_);
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
							result = TRUE;
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
							return result;
#line 2413 "app-window.c"
						} else {
							gboolean _tmp36_ = FALSE;
							gboolean _tmp37_ = FALSE;
							gboolean _tmp38_ = FALSE;
							GtkTextDirection _tmp39_ = 0;
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
							_tmp39_ = direction;
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
							if (_tmp39_ == GTK_TEXT_DIR_LTR) {
#line 2423 "app-window.c"
								GdkEventKey* _tmp40_ = NULL;
								guint _tmp41_ = 0U;
#line 386 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
								_tmp40_ = event;
#line 386 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
								_tmp41_ = _tmp40_->keyval;
#line 386 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
								_tmp38_ = _tmp41_ == ((guint) GDK_KEY_Left);
#line 2432 "app-window.c"
							} else {
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
								_tmp38_ = FALSE;
#line 2436 "app-window.c"
							}
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
							if (_tmp38_) {
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
								_tmp37_ = TRUE;
#line 2442 "app-window.c"
							} else {
								gboolean _tmp42_ = FALSE;
								GtkTextDirection _tmp43_ = 0;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
								_tmp43_ = direction;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
								if (_tmp43_ == GTK_TEXT_DIR_RTL) {
#line 2450 "app-window.c"
									GdkEventKey* _tmp44_ = NULL;
									guint _tmp45_ = 0U;
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
									_tmp44_ = event;
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
									_tmp45_ = _tmp44_->keyval;
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
									_tmp42_ = _tmp45_ == ((guint) GDK_KEY_Right);
#line 2459 "app-window.c"
								} else {
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
									_tmp42_ = FALSE;
#line 2463 "app-window.c"
								}
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
								_tmp37_ = _tmp42_;
#line 2467 "app-window.c"
							}
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
							if (_tmp37_) {
#line 2471 "app-window.c"
								GdkEventKey* _tmp46_ = NULL;
								GdkModifierType _tmp47_ = 0;
								GdkModifierType _tmp48_ = 0;
#line 389 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
								_tmp46_ = event;
#line 389 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
								_tmp47_ = _tmp46_->state;
#line 389 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
								_tmp48_ = default_modifiers;
#line 389 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
								_tmp36_ = (_tmp47_ & _tmp48_) == GDK_MOD1_MASK;
#line 2483 "app-window.c"
							} else {
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
								_tmp36_ = FALSE;
#line 2487 "app-window.c"
							}
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
							if (_tmp36_) {
#line 2491 "app-window.c"
								BoxesTopbar* _tmp49_ = NULL;
#line 390 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
								_tmp49_ = self->topbar;
#line 390 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
								boxes_topbar_click_back_button (_tmp49_);
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
								result = TRUE;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
								return result;
#line 2501 "app-window.c"
							} else {
								GdkEventKey* _tmp50_ = NULL;
								guint _tmp51_ = 0U;
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
								_tmp50_ = event;
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
								_tmp51_ = _tmp50_->keyval;
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
								if (_tmp51_ == ((guint) GDK_KEY_Escape)) {
#line 2511 "app-window.c"
									BoxesTopbar* _tmp52_ = NULL;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
									_tmp52_ = self->topbar;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
									boxes_topbar_click_cancel_button (_tmp52_);
#line 2517 "app-window.c"
								}
							}
						}
					}
				}
			}
		}
	}
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	result = FALSE;
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	return result;
#line 2530 "app-window.c"
}


static gboolean _boxes_app_window_on_key_pressed_gtk_widget_key_press_event (GtkWidget* _sender, GdkEventKey* event, gpointer self) {
	gboolean result;
	result = boxes_app_window_on_key_pressed ((BoxesAppWindow*) self, _sender, event);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	return result;
#line 2539 "app-window.c"
}


static gboolean __lambda216_ (BoxesAppWindow* self) {
	gboolean result = FALSE;
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	self->priv->configure_id = (guint) 0;
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	boxes_app_window_save_window_geometry (self);
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	result = FALSE;
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	return result;
#line 2553 "app-window.c"
}


static gboolean ___lambda216__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda216_ ((BoxesAppWindow*) self);
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	return result;
#line 2562 "app-window.c"
}


static gboolean boxes_app_window_on_configure_event (BoxesAppWindow* self) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	guint _tmp2_ = 0U;
	guint _tmp4_ = 0U;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp0_ = boxes_app_window_get_fullscreened (self);
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp1_ = _tmp0_;
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	if (_tmp1_) {
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		result = FALSE;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		return result;
#line 2584 "app-window.c"
	}
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp2_ = self->priv->configure_id;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	if (_tmp2_ != ((guint) 0)) {
#line 2590 "app-window.c"
		guint _tmp3_ = 0U;
#line 405 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp3_ = self->priv->configure_id;
#line 405 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		g_source_remove (_tmp3_);
#line 2596 "app-window.c"
	}
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp4_ = g_timeout_add_full (G_PRIORITY_DEFAULT, BOXES_APP_WINDOW_configure_id_timeout, ___lambda216__gsource_func, g_object_ref (self), g_object_unref);
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	self->priv->configure_id = _tmp4_;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	result = FALSE;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	return result;
#line 2606 "app-window.c"
}


static gboolean _boxes_app_window_on_configure_event_gtk_widget_configure_event (GtkWidget* _sender, GdkEventConfigure* event, gpointer self) {
	gboolean result;
	result = boxes_app_window_on_configure_event ((BoxesAppWindow*) self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	return result;
#line 2615 "app-window.c"
}


static gboolean boxes_app_window_on_window_state_event (BoxesAppWindow* self, GdkEventWindowState* event) {
	gboolean result = FALSE;
	GdkEventWindowState* _tmp0_ = NULL;
	GdkWindowState _tmp1_ = 0;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
	GSettings* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	gboolean _tmp6_ = FALSE;
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp0_ = event;
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp1_ = _tmp0_->changed_mask;
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	if ((_tmp1_ & GDK_WINDOW_STATE_FULLSCREEN) == GDK_WINDOW_STATE_FULLSCREEN) {
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		g_object_notify ((GObject*) self, "fullscreened");
#line 2640 "app-window.c"
	}
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp2_ = boxes_app_window_get_fullscreened (self);
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp3_ = _tmp2_;
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	if (_tmp3_) {
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		result = FALSE;
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		return result;
#line 2652 "app-window.c"
	}
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp4_ = self->settings;
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp5_ = boxes_app_window_get_maximized (self);
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp6_ = _tmp5_;
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_settings_set_boolean (_tmp4_, "window-maximized", _tmp6_);
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	result = FALSE;
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	return result;
#line 2666 "app-window.c"
}


static gboolean _boxes_app_window_on_window_state_event_gtk_widget_window_state_event (GtkWidget* _sender, GdkEventWindowState* event, gpointer self) {
	gboolean result;
	result = boxes_app_window_on_window_state_event ((BoxesAppWindow*) self, event);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	return result;
#line 2675 "app-window.c"
}


static gboolean boxes_app_window_on_delete_event (BoxesAppWindow* self) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	BoxesCollectionItem* _tmp1_ = NULL;
	BoxesCollectionItem* _tmp2_ = NULL;
	BoxesCollectionItem* _tmp5_ = NULL;
	BoxesCollectionItem* _tmp6_ = NULL;
	BoxesApp* _tmp12_ = NULL;
	gboolean _tmp13_ = FALSE;
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 431 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp1_ = boxes_app_window_get_current_item (self);
#line 431 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp2_ = _tmp1_;
#line 431 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	if (_tmp2_ == NULL) {
#line 431 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp0_ = TRUE;
#line 2698 "app-window.c"
	} else {
		BoxesCollectionItem* _tmp3_ = NULL;
		BoxesCollectionItem* _tmp4_ = NULL;
#line 431 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp3_ = boxes_app_window_get_current_item (self);
#line 431 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp4_ = _tmp3_;
#line 431 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp0_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, BOXES_TYPE_MACHINE);
#line 2708 "app-window.c"
	}
#line 431 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_val_if_fail (_tmp0_, FALSE);
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp5_ = boxes_app_window_get_current_item (self);
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp6_ = _tmp5_;
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	if (_tmp6_ != NULL) {
#line 2718 "app-window.c"
		BoxesMachine* machine = NULL;
		BoxesCollectionItem* _tmp7_ = NULL;
		BoxesCollectionItem* _tmp8_ = NULL;
		BoxesMachine* _tmp9_ = NULL;
		BoxesMachine* _tmp10_ = NULL;
		BoxesMachine* _tmp11_ = NULL;
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp7_ = boxes_app_window_get_current_item (self);
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp8_ = _tmp7_;
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp9_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp8_) : NULL);
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		machine = _tmp9_;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp10_ = machine;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		boxes_machine_set_window (_tmp10_, NULL);
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp11_ = machine;
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		boxes_machine_schedule_autosave (_tmp11_);
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_g_object_unref0 (machine);
#line 2743 "app-window.c"
	}
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp12_ = boxes_app_app;
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp13_ = boxes_app_remove_window (_tmp12_, self);
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	result = _tmp13_;
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	return result;
#line 2753 "app-window.c"
}


static gboolean _boxes_app_window_on_delete_event_gtk_widget_delete_event (GtkWidget* _sender, GdkEventAny* event, gpointer self) {
	gboolean result;
	result = boxes_app_window_on_delete_event ((BoxesAppWindow*) self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	return result;
#line 2762 "app-window.c"
}


static void boxes_app_window_on_machine_state_notify (BoxesAppWindow* self) {
	gboolean _tmp0_ = FALSE;
	BoxesApp* _tmp1_ = NULL;
	BoxesAppWindow* _tmp2_ = NULL;
	BoxesAppWindow* _tmp3_ = NULL;
#line 443 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_if_fail (self != NULL);
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp1_ = boxes_app_app;
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp2_ = boxes_app_get_main_window (_tmp1_);
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp3_ = _tmp2_;
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	if (self != _tmp3_) {
#line 2781 "app-window.c"
		BoxesCollectionItem* _tmp4_ = NULL;
		BoxesCollectionItem* _tmp5_ = NULL;
		BoxesMachineMachineState _tmp6_ = 0;
		BoxesMachineMachineState _tmp7_ = 0;
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp4_ = boxes_app_window_get_current_item (self);
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp5_ = _tmp4_;
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp6_ = boxes_machine_get_state (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp5_) : NULL);
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp7_ = _tmp6_;
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp0_ = _tmp7_ != BOXES_MACHINE_MACHINE_STATE_RUNNING;
#line 2796 "app-window.c"
	} else {
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp0_ = FALSE;
#line 2800 "app-window.c"
	}
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	if (_tmp0_) {
#line 445 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		boxes_app_window_on_delete_event (self);
#line 2806 "app-window.c"
	}
}


static void boxes_app_window_on_machine_deleted_notify (BoxesAppWindow* self) {
	gboolean _tmp0_ = FALSE;
	BoxesApp* _tmp1_ = NULL;
	BoxesAppWindow* _tmp2_ = NULL;
	BoxesAppWindow* _tmp3_ = NULL;
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_if_fail (self != NULL);
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp1_ = boxes_app_app;
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp2_ = boxes_app_get_main_window (_tmp1_);
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp3_ = _tmp2_;
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	if (self != _tmp3_) {
#line 2826 "app-window.c"
		BoxesCollectionItem* _tmp4_ = NULL;
		BoxesCollectionItem* _tmp5_ = NULL;
		gboolean _tmp6_ = FALSE;
		gboolean _tmp7_ = FALSE;
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp4_ = boxes_app_window_get_current_item (self);
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp5_ = _tmp4_;
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp6_ = boxes_machine_get_deleted (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp5_) : NULL);
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp7_ = _tmp6_;
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp0_ = _tmp7_;
#line 2841 "app-window.c"
	} else {
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp0_ = FALSE;
#line 2845 "app-window.c"
	}
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	if (_tmp0_) {
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		boxes_app_window_on_delete_event (self);
#line 2851 "app-window.c"
	}
}


static BoxesUIState boxes_app_window_real_get_previous_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesAppWindow* self;
	BoxesUIState _tmp0_ = 0;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	self = (BoxesAppWindow*) base;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp0_ = self->priv->_previous_ui_state;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	result = _tmp0_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	return result;
#line 2868 "app-window.c"
}


static void boxes_app_window_real_set_previous_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesAppWindow* self;
	BoxesUIState _tmp0_ = 0;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	self = (BoxesAppWindow*) base;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp0_ = value;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	self->priv->_previous_ui_state = _tmp0_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_object_notify ((GObject *) self, "previous-ui-state");
#line 2883 "app-window.c"
}


static BoxesUIState boxes_app_window_real_get_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesAppWindow* self;
	BoxesUIState _tmp0_ = 0;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	self = (BoxesAppWindow*) base;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp0_ = self->priv->_ui_state;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	result = _tmp0_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	return result;
#line 2899 "app-window.c"
}


static void boxes_app_window_real_set_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesAppWindow* self;
	BoxesUIState _tmp0_ = 0;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	self = (BoxesAppWindow*) base;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp0_ = value;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	self->priv->_ui_state = _tmp0_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_object_notify ((GObject *) self, "ui-state");
#line 2914 "app-window.c"
}


BoxesCollectionItem* boxes_app_window_get_current_item (BoxesAppWindow* self) {
	BoxesCollectionItem* result;
	BoxesCollectionItem* _tmp0_ = NULL;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp0_ = self->priv->_current_item;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	result = _tmp0_;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	return result;
#line 2929 "app-window.c"
}


static void _boxes_app_window_on_machine_state_notify_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	boxes_app_window_on_machine_state_notify ((BoxesAppWindow*) self);
#line 2936 "app-window.c"
}


static void _boxes_app_window_on_machine_deleted_notify_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	boxes_app_window_on_machine_deleted_notify ((BoxesAppWindow*) self);
#line 2943 "app-window.c"
}


void boxes_app_window_set_current_item (BoxesAppWindow* self, BoxesCollectionItem* value) {
	BoxesCollectionItem* _tmp0_ = NULL;
	BoxesCollectionItem* _tmp3_ = NULL;
	BoxesCollectionItem* _tmp4_ = NULL;
	BoxesCollectionItem* _tmp5_ = NULL;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_if_fail (self != NULL);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp0_ = self->priv->_current_item;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	if (_tmp0_ != NULL) {
#line 2958 "app-window.c"
		BoxesCollectionItem* _tmp1_ = NULL;
		gulong _tmp2_ = 0UL;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp1_ = self->priv->_current_item;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp2_ = self->priv->machine_state_notify_id;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		g_signal_handler_disconnect ((GObject*) _tmp1_, _tmp2_);
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		self->priv->machine_state_notify_id = (gulong) 0;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		self->priv->machine_deleted_notify_id = (gulong) 0;
#line 2971 "app-window.c"
	}
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp3_ = value;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->priv->_current_item);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	self->priv->_current_item = _tmp4_;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp5_ = self->priv->_current_item;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	if (_tmp5_ != NULL) {
#line 2985 "app-window.c"
		BoxesMachine* machine = NULL;
		BoxesCollectionItem* _tmp6_ = NULL;
		BoxesMachine* _tmp7_ = NULL;
		BoxesMachine* _tmp8_ = NULL;
		gulong _tmp9_ = 0UL;
		BoxesMachine* _tmp10_ = NULL;
		gulong _tmp11_ = 0UL;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp6_ = self->priv->_current_item;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp7_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp6_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp6_) : NULL);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		machine = _tmp7_;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp8_ = machine;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp9_ = g_signal_connect_object ((GObject*) _tmp8_, "notify::state", (GCallback) _boxes_app_window_on_machine_state_notify_g_object_notify, self, 0);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		self->priv->machine_state_notify_id = _tmp9_;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp10_ = machine;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_tmp11_ = g_signal_connect_object ((GObject*) _tmp10_, "notify::deleted", (GCallback) _boxes_app_window_on_machine_deleted_notify_g_object_notify, self, 0);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		self->priv->machine_deleted_notify_id = _tmp11_;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		_g_object_unref0 (machine);
#line 3013 "app-window.c"
	}
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_object_notify ((GObject *) self, "current-item");
#line 3017 "app-window.c"
}


gboolean boxes_app_window_get_fullscreened (BoxesAppWindow* self) {
	gboolean result;
	GdkWindow* _tmp0_ = NULL;
	GdkWindowState _tmp1_ = 0;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp0_ = gtk_widget_get_window ((GtkWidget*) self);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp1_ = gdk_window_get_state (_tmp0_);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	result = (_tmp1_ & GDK_WINDOW_STATE_FULLSCREEN) == GDK_WINDOW_STATE_FULLSCREEN;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	return result;
#line 3035 "app-window.c"
}


void boxes_app_window_set_fullscreened (BoxesAppWindow* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_if_fail (self != NULL);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp0_ = value;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	if (_tmp0_) {
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		gtk_window_fullscreen ((GtkWindow*) self);
#line 3049 "app-window.c"
	} else {
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		gtk_window_unfullscreen ((GtkWindow*) self);
#line 3053 "app-window.c"
	}
}


static gboolean boxes_app_window_get_maximized (BoxesAppWindow* self) {
	gboolean result;
	GdkWindow* _tmp0_ = NULL;
	GdkWindowState _tmp1_ = 0;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp0_ = gtk_widget_get_window ((GtkWidget*) self);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp1_ = gdk_window_get_state (_tmp0_);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	result = (_tmp1_ & GDK_WINDOW_STATE_MAXIMIZED) == GDK_WINDOW_STATE_MAXIMIZED;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	return result;
#line 3072 "app-window.c"
}


gboolean boxes_app_window_get_selection_mode (BoxesAppWindow* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp0_ = self->priv->_selection_mode;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	result = _tmp0_;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	return result;
#line 3087 "app-window.c"
}


void boxes_app_window_set_selection_mode (BoxesAppWindow* self, gboolean value) {
	BoxesUIState _tmp0_ = 0;
	BoxesUIState _tmp1_ = 0;
	gboolean _tmp2_ = FALSE;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_if_fail (self != NULL);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp0_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp1_ = _tmp0_;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_if_fail (_tmp1_ == BOXES_UI_STATE_COLLECTION);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp2_ = value;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	self->priv->_selection_mode = _tmp2_;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_object_notify ((GObject *) self, "selection-mode");
#line 3109 "app-window.c"
}


BoxesNotificationbar* boxes_app_window_get_notificationbar (BoxesAppWindow* self) {
	BoxesNotificationbar* result;
	BoxesUIState _tmp0_ = 0;
	BoxesUIState _tmp1_ = 0;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp0_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp1_ = _tmp0_;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	switch (_tmp1_) {
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		case BOXES_UI_STATE_WIZARD:
#line 3127 "app-window.c"
		{
			BoxesWizardWindow* _tmp2_ = NULL;
			BoxesNotificationbar* _tmp3_ = NULL;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp2_ = self->wizard_window;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp3_ = _tmp2_->notificationbar;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			result = _tmp3_;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			return result;
#line 3139 "app-window.c"
		}
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		case BOXES_UI_STATE_PROPERTIES:
#line 3143 "app-window.c"
		{
			BoxesPropertiesWindow* _tmp4_ = NULL;
			BoxesNotificationbar* _tmp5_ = NULL;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp4_ = self->props_window;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp5_ = _tmp4_->notificationbar;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			result = _tmp5_;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			return result;
#line 3155 "app-window.c"
		}
		default:
		{
			BoxesNotificationbar* _tmp6_ = NULL;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp6_ = self->priv->_notificationbar;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			result = _tmp6_;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			return result;
#line 3166 "app-window.c"
		}
	}
}


BoxesAppWindowViewType boxes_app_window_get_view_type (BoxesAppWindow* self) {
	BoxesAppWindowViewType result;
	BoxesAppWindowViewType _tmp0_ = 0;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp0_ = self->priv->_view_type;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	result = _tmp0_;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	return result;
#line 3183 "app-window.c"
}


void boxes_app_window_set_view_type (BoxesAppWindow* self, BoxesAppWindowViewType value) {
	BoxesAppWindowViewType _tmp0_ = 0;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_if_fail (self != NULL);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp0_ = value;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	self->priv->_view_type = _tmp0_;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_object_notify ((GObject *) self, "view-type");
#line 3197 "app-window.c"
}


BoxesICollectionView* boxes_app_window_get_view (BoxesAppWindow* self) {
	BoxesICollectionView* result;
	BoxesAppWindowViewType _tmp0_ = 0;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_tmp0_ = self->priv->_view_type;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	switch (_tmp0_) {
#line 3210 "app-window.c"
		default:
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		case BOXES_APP_WINDOW_VIEW_TYPE_ICON:
#line 3214 "app-window.c"
		{
			BoxesIconView* _tmp1_ = NULL;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp1_ = self->priv->icon_view;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			result = (BoxesICollectionView*) _tmp1_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			return result;
#line 3223 "app-window.c"
		}
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		case BOXES_APP_WINDOW_VIEW_TYPE_LIST:
#line 3227 "app-window.c"
		{
			BoxesListView* _tmp2_ = NULL;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			_tmp2_ = self->priv->list_view;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			result = (BoxesICollectionView*) _tmp2_;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
			return result;
#line 3236 "app-window.c"
		}
	}
}


static void boxes_app_window_class_init (BoxesAppWindowClass * klass) {
	gint BoxesAppWindow_private_offset;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	boxes_app_window_parent_class = g_type_class_peek_parent (klass);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_type_class_add_private (klass, sizeof (BoxesAppWindowPrivate));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_app_window_get_property;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_app_window_set_property;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_app_window_finalize;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_APP_WINDOW_PREVIOUS_UI_STATE, g_param_spec_enum ("previous-ui-state", "previous-ui-state", "previous-ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_APP_WINDOW_UI_STATE, g_param_spec_enum ("ui-state", "ui-state", "ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_APP_WINDOW_CURRENT_ITEM, g_param_spec_object ("current-item", "current-item", "current-item", BOXES_TYPE_COLLECTION_ITEM, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_APP_WINDOW_FULLSCREENED, g_param_spec_boolean ("fullscreened", "fullscreened", "fullscreened", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_APP_WINDOW_SELECTION_MODE, g_param_spec_boolean ("selection-mode", "selection-mode", "selection-mode", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_APP_WINDOW_NOTIFICATIONBAR, g_param_spec_object ("notificationbar", "notificationbar", "notificationbar", BOXES_TYPE_NOTIFICATIONBAR, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_APP_WINDOW_VIEW_TYPE, g_param_spec_enum ("view-type", "view-type", "view-type", BOXES_APP_WINDOW_TYPE_VIEW_TYPE, BOXES_APP_WINDOW_VIEW_TYPE_ICON, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_APP_WINDOW_VIEW, g_param_spec_object ("view", "view", "view", BOXES_TYPE_ICOLLECTION_VIEW, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	BoxesAppWindow_private_offset = g_type_class_get_instance_private_offset (klass);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/app-window.ui");
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_signal_new ("item_selected", BOXES_TYPE_APP_WINDOW, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, BOXES_TYPE_COLLECTION_ITEM);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "searchbar", FALSE, G_STRUCT_OFFSET (BoxesAppWindow, searchbar));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "topbar", FALSE, G_STRUCT_OFFSET (BoxesAppWindow, topbar));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "selectionbar", FALSE, G_STRUCT_OFFSET (BoxesAppWindow, selectionbar));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "display_page", FALSE, G_STRUCT_OFFSET (BoxesAppWindow, display_page));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "empty_boxes", FALSE, G_STRUCT_OFFSET (BoxesAppWindow, empty_boxes));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "below_bin", FALSE, G_STRUCT_OFFSET (BoxesAppWindow, below_bin));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "icon_view", FALSE, BoxesAppWindow_private_offset + G_STRUCT_OFFSET (BoxesAppWindowPrivate, icon_view));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "list_view", FALSE, BoxesAppWindow_private_offset + G_STRUCT_OFFSET (BoxesAppWindowPrivate, list_view));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "_notificationbar", FALSE, BoxesAppWindow_private_offset + G_STRUCT_OFFSET (BoxesAppWindowPrivate, _notificationbar));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_key_pressed", G_CALLBACK(_boxes_app_window_on_key_pressed_gtk_widget_key_press_event));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_configure_event", G_CALLBACK(_boxes_app_window_on_configure_event_gtk_widget_configure_event));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_window_state_event", G_CALLBACK(_boxes_app_window_on_window_state_event_gtk_widget_window_state_event));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_delete_event", G_CALLBACK(_boxes_app_window_on_delete_event_gtk_widget_delete_event));
#line 3302 "app-window.c"
}


static void boxes_app_window_boxes_ui_interface_init (BoxesUIIface * iface) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	boxes_app_window_boxes_ui_parent_iface = g_type_interface_peek_parent (iface);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	iface->get_previous_ui_state = boxes_app_window_real_get_previous_ui_state;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	iface->set_previous_ui_state = boxes_app_window_real_set_previous_ui_state;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	iface->get_ui_state = boxes_app_window_real_get_ui_state;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	iface->set_ui_state = boxes_app_window_real_set_ui_state;
#line 3317 "app-window.c"
}


static void boxes_app_window_instance_init (BoxesAppWindow * self) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	self->priv = BOXES_APP_WINDOW_GET_PRIVATE (self);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	self->priv->_view_type = BOXES_APP_WINDOW_VIEW_TYPE_ICON;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_type_ensure (BOXES_TYPE_DISPLAY_PAGE);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_type_ensure (BOXES_TYPE_TOPBAR);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_type_ensure (BOXES_TYPE_NOTIFICATIONBAR);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_type_ensure (BOXES_TYPE_EMPTY_BOXES);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_type_ensure (BOXES_TYPE_LIST_VIEW);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_type_ensure (BOXES_TYPE_SEARCHBAR);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_type_ensure (BOXES_TYPE_ICON_VIEW);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	g_type_ensure (BOXES_TYPE_SELECTIONBAR);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 3344 "app-window.c"
}


static void boxes_app_window_finalize (GObject* obj) {
	BoxesAppWindow * self;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_APP_WINDOW, BoxesAppWindow);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->priv->_current_item);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->priv->status_bind);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->wizard_window);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->props_window);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->searchbar);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->topbar);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->selectionbar);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->display_page);
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->empty_boxes);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->below_bin);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->priv->icon_view);
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->priv->list_view);
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	self->priv->views = (_vala_array_free (self->priv->views, self->priv->views_length1, (GDestroyNotify) g_object_unref), NULL);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->settings);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->priv->_notificationbar);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->priv->group);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	G_OBJECT_CLASS (boxes_app_window_parent_class)->finalize (obj);
#line 3386 "app-window.c"
}


GType boxes_app_window_get_type (void) {
	static volatile gsize boxes_app_window_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_app_window_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesAppWindowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_app_window_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesAppWindow), 0, (GInstanceInitFunc) boxes_app_window_instance_init, NULL };
		static const GInterfaceInfo boxes_ui_info = { (GInterfaceInitFunc) boxes_app_window_boxes_ui_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType boxes_app_window_type_id;
		boxes_app_window_type_id = g_type_register_static (gtk_application_window_get_type (), "BoxesAppWindow", &g_define_type_info, 0);
		g_type_add_interface_static (boxes_app_window_type_id, BOXES_TYPE_UI, &boxes_ui_info);
		g_once_init_leave (&boxes_app_window_type_id__volatile, boxes_app_window_type_id);
	}
	return boxes_app_window_type_id__volatile;
}


static void _vala_boxes_app_window_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesAppWindow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_APP_WINDOW, BoxesAppWindow);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	switch (property_id) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		case BOXES_APP_WINDOW_PREVIOUS_UI_STATE:
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		g_value_set_enum (value, boxes_ui_get_previous_ui_state ((BoxesUI*) self));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		break;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		case BOXES_APP_WINDOW_UI_STATE:
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		g_value_set_enum (value, boxes_ui_get_ui_state ((BoxesUI*) self));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		break;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		case BOXES_APP_WINDOW_CURRENT_ITEM:
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		g_value_set_object (value, boxes_app_window_get_current_item (self));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		break;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		case BOXES_APP_WINDOW_FULLSCREENED:
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		g_value_set_boolean (value, boxes_app_window_get_fullscreened (self));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		break;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		case BOXES_APP_WINDOW_SELECTION_MODE:
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		g_value_set_boolean (value, boxes_app_window_get_selection_mode (self));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		break;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		case BOXES_APP_WINDOW_NOTIFICATIONBAR:
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		g_value_set_object (value, boxes_app_window_get_notificationbar (self));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		break;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		case BOXES_APP_WINDOW_VIEW_TYPE:
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		g_value_set_enum (value, boxes_app_window_get_view_type (self));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		break;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		case BOXES_APP_WINDOW_VIEW:
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		g_value_set_object (value, boxes_app_window_get_view (self));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		break;
#line 3457 "app-window.c"
		default:
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		break;
#line 3463 "app-window.c"
	}
}


static void _vala_boxes_app_window_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesAppWindow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_APP_WINDOW, BoxesAppWindow);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
	switch (property_id) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		case BOXES_APP_WINDOW_PREVIOUS_UI_STATE:
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		boxes_ui_set_previous_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		break;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		case BOXES_APP_WINDOW_UI_STATE:
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		boxes_ui_set_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		break;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		case BOXES_APP_WINDOW_CURRENT_ITEM:
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		boxes_app_window_set_current_item (self, g_value_get_object (value));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		break;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		case BOXES_APP_WINDOW_FULLSCREENED:
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		boxes_app_window_set_fullscreened (self, g_value_get_boolean (value));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		break;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		case BOXES_APP_WINDOW_SELECTION_MODE:
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		boxes_app_window_set_selection_mode (self, g_value_get_boolean (value));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		break;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		case BOXES_APP_WINDOW_VIEW_TYPE:
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		boxes_app_window_set_view_type (self, g_value_get_enum (value));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		break;
#line 3509 "app-window.c"
		default:
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app-window.vala"
		break;
#line 3515 "app-window.c"
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



